local C = require("classic")

-- Graphics: transparent color is yellow
g_skel1n            = kts.Graphic("assets/skel1n.bmp", 255,255,0)
g_skel1e            = kts.Graphic("assets/skel1e.bmp", 255,255,0)
g_skel1s            = kts.Graphic("assets/skel1s.bmp", 255,255,0)
g_skel1w            = kts.Graphic("assets/skel1w.bmp", 255,255,0)
g_skel2n            = kts.Graphic("assets/skel2n.bmp", 255,255,0, 0,4) --offset 4 pixels to lunge during attack
g_skel2e            = kts.Graphic("assets/skel2e.bmp", 255,255,0, -4,0)--"
g_skel2s            = kts.Graphic("assets/skel2s.bmp", 255,255,0, 0,-4)--"
g_skel2w            = kts.Graphic("assets/skel2w.bmp", 255,255,0, 4,0) --"
g_skel3n            = kts.Graphic("assets/skel3n.bmp", 255,255,0)
g_skel3e            = kts.Graphic("assets/skel3e.bmp", 255,255,0)
g_skel3s            = kts.Graphic("assets/skel3s.bmp", 255,255,0)
g_skel3w            = kts.Graphic("assets/skel3w.bmp", 255,255,0)
g_skel4n            = kts.Graphic("assets/skel4n.bmp", 255,255,0)
g_skel4e            = kts.Graphic("assets/skel4e.bmp", 255,255,0)
g_skel4s            = kts.Graphic("assets/skel4s.bmp", 255,255,0)
g_skel4w            = kts.Graphic("assets/skel4w.bmp", 255,255,0)

g_dead_skel = kts.Graphic("assets/dead_skel.bmp", 255,255,0)

-- Animation
a_skeleton = kts.Anim {
    g_skel1n, g_skel1e, g_skel1s, g_skel1w,  -- Normal
    g_skel3n, g_skel3e, g_skel3s, g_skel3w,  -- Melee backswing
    g_skel2n, g_skel2e, g_skel2s, g_skel2w,  -- Melee downswing
    g_skel4n, g_skel4e, g_skel4s, g_skel4w   -- Parrying
}

--- Tiles
t_dead_skel = kts.Tile(C.floor & { graphic = g_dead_skel, depth = -1 } )

--assets
s_skeleton1 = kts.Sound("assets/skeleton1.wav")
s_skeleton2 = kts.Sound("assets/skeleton2.wav")
s_skeleton3 = kts.Sound("assets/skeleton3.wav")
s_skeleton4 = kts.Sound("assets/potiondrop.wav")

function snd_skeleton1() 
   kts.PlaySound(cxt.pos, s_skeleton1, 15000)
end
function snd_skeleton2()
   kts.PlaySound(cxt.pos, s_skeleton2, 15000)
end
function snd_skeleton3()
   kts.PlaySound(cxt.pos, s_skeleton3, 15000)
end
function snd_skeleton4()
   kts.PlaySound(cxt.pos, s_skeleton4, 15000)
end


function potion_drop()
  -- drop a potion item at actor's current position (if tile not already occupied)
	local success = kts.PlaceItem(kts.GetPos(cxt.actor), C.i_potion)
	if success then snd_skeleton4() end
end

function skel_regenerate()
  --remove skeleton, wait 1-10 secs, play sound, remove corpse, add skeleton stunned for 1 sec
  local pos = kts.GetPos(cxt.actor)
  kts.DestroyCreature(cxt.actor, "poison") --poison = leave corpse no blood
  kts.Delay(kts.RandomRange(1000,10000))
  snd_skeleton2()
  kts.RemoveTile(pos, t_dead_skel)
  kts.AddMonster(pos, m_skelor_fist)
  kts.Delay(1000)
end

function skeleton_damage()
  --regenerate on coin flip, otherwise 75% chance dies & drops potion
  snd_skeleton1()
  if kts.RandomChance(.5) then
    skel_regenerate()
  elseif kts.RandomChance(.75) then
    potion_drop()
    kts.DestroyCreature(cxt.actor, "poison")
  end
end
   
--The monster's weapon (i.e. fists)
i_skelfist = kts.ItemType {
    --borrowed from Worst's Living Armour mod
    type = "held",

    melee_backswing_time = C.ts*2,
    melee_downswing_time = C.ts*3,
    melee_damage = C.rng_range(1, 1),
    melee_stun_time = C.rng_time_range(0, 4),
    melee_tile_damage = 1,
}

-- The monster type
m_skeleton = {
   type = "walking",

   -- general properties:
   health = 100,
   speed = 90, --% of knight speed
   anim = a_skeleton,
   corpse_tiles = { t_dead_skel },
   on_damage = skeleton_damage,
   on_attack = snd_skeleton1,
   on_death = snd_skeleton3,
   
   -- properties specific to walking monsters:
   weapon = i_skelfist, --fists only
   ai_avoid = C.all_open_pit_tiles, --smart enough not to fall in pits
   ai_fear = {C.i_wand_of_destruction, C.i_wand_of_undeath}, --avoid players with wands
}

--Skeleton monster type armed with fist
m_skelor_fist = kts.MonsterType( m_skeleton & { weapon = i_skelfist, anim = a_skeleton } )


